﻿function Get-SCStorageCSVOvercommitment
{
    param
    (
        [Parameter(Mandatory=$true, HelpMessage='VMM Server')]
        [String]
        $VMMServer
    )
    
    $CSVArray=@()
    $Cluster=Get-SCVMHostCluster -VMMServer $VMMServer|Out-GridView -PassThru
    $Hosts=Get-SCVMHostCluster -VMMServer $VMMServer -Name $Cluster|Get-SCVMHost
    $CSVs=Get-ClusterSharedVolume -Cluster $Cluster.Name
    $i=0

    foreach ($CSV in $CSVs)
    {
        Write-Progress -Activity "In Progress" -PercentComplete $i
        $CSVInfo=$CSV|Select-Object -Property Name -ExpandProperty SharedVolumeInfo
        $OvercommitSpace=0
        $Overcommited="false"
            foreach($Hoster in $Hosts)
            {
                $Volume=$CSVInfo.FriendlyVolumeName+"\*"
                $VMs=Get-SCVirtualMachine -VMMServer $VMMServer -VMHost $Hoster
                    foreach($VM in $VMs)
                    {
                        $VHDs=Get-SCVirtualHardDisk -VMMServer $VMMServer -VM $VM|Where-Object{$_.Location -like $Volume}
                        foreach($VHD in $VHDs)
                        {
                            $OvercommitSpace = $OvercommitSpace + $VHD.MaximumSize
                        }
                    }
            }
            if($CSVInfo.Partition.Size -le $OvercommitSpace)
            {
                $Overcommited = "true"
            }
            $Info = New-Object PSObject -Property @{
                Name=$CSV.Name
                Path=$CSVInfo.FriendlyVolumeName
                Size=$CSVInfo.Partition.Size
                FreeSpace=$CSVInfo.Partition.FreeSpace
                UsedSpace=$CSVInfo.Partition.UsedSpace
                Overcommited=$Overcommited
                Overcommitment=$OvercommitSpace
                OvercommitedPercentage=((($OvercommitSpace/1GB)/($CSVInfo.Partition.Size/1GB))*100)-100
            }
            $CSVArray += $Info
            $i=$i+(100/$CSVs.Length)
    }

    $CSVArray|Select-Object -Property Name,Path,@{Label="Size(GB)";Expression={"{0:N2}" -f ($_.Size/1GB)}},@{Label="Free(GB)";Expression={"{0:N2}" -f ($_.FreeSpace/1GB)}},@{Label="Used(GB)";Expression={"{0:N2}" -f ($_.UsedSpace/1GB)}},Overcommited,@{Label="Effective Used(GB)";Expression={"{0:N2}" -f ($_.Overcommitment/1GB)}},@{Label="Overcommited %";Expression={"{0:N2}" -f ($_.OvercommitedPercentage)}} | Out-GridView -Title "CSV-Overcommitment-Status for $Cluster"

}